@@ -21,11 +21,11 @@ CPAN::Mini::Inject - Inject modules into a CPAN::Mini mirror.
 
 =head1 VERSION
 
-Version 0.27
+Version 0.29
 
 =cut
 
-our $VERSION = '0.27';
+our $VERSION = '0.29';
 our @ISA     = qw( CPAN::Mini );
 
 =head1 Synopsis
@@ -310,12 +310,12 @@ sub add {
 
   # remove old version from the list
   @{ $self->{modulelist} }
-   = grep { $_ !~ m/$options{module}\s+/ } @{ $self->{modulelist} };
+   = grep { $_ !~ m/\A$options{module}\s+/ } @{ $self->{modulelist} };
 
   push(
     @{ $self->{modulelist} },
     _fmtmodule(
-      $options{module}, $self->{authdir} . "/$modulefile",
+      $options{module}, File::Spec::Unix->catfile( File::Spec->splitdir( $self->{authdir} ), $modulefile ),
       $options{version}
     )
   );
@@ -415,8 +415,10 @@ sub updauthors {
   AUTHOR:
   for my $modline ( @{ $self->{modulelist} } ) {
     my ( $module, $version, $file ) = split( /\s+/, $modline );
-    my $author
-     = ( split( "/", $file, 4 ) )[2]; # extract the author from the path
+
+    # extract the author from the path
+    my @dirs = File::Spec->splitdir( $file );
+    my $author = $dirs[2];
 
     next AUTHOR if defined $author_ids_in_repo{$author};
     next AUTHOR if defined $authors_added{$author};
@@ -510,23 +512,6 @@ sub _optionchk {
   return join ' ', @missing;
 }
 
-# TODO this stuff has moved to ::Config
-sub _findcfg {
-  my @try = (
-    ( defined $ENV{MCPANI_CONFIG} ? ( [ $ENV{MCPANI_CONFIG} ] ) : () ),
-    (
-      defined $ENV{HOME} ? ( [ $ENV{HOME}, '.mcpani', 'config' ] ) : ()
-    ),
-  );
-  push @try, ['/usr/local/etc/mcpani'], ['/etc/mcpani']
-   unless $^O =~ /MSWin32/;
-  for my $try ( @try ) {
-    my $file = File::Spec->catfile( @$try );
-    return $file if -r $file;
-  }
-  return undef;
-}
-
 sub _make_path {
   my $um = umask 0;
   make_path( @_ );
@@ -547,17 +532,11 @@ sub _authordir {
   return return File::Spec->catdir( @author );
 }
 
-#sub _fmtmodule {
-#  my ( $module, $file, $version ) = @_;
-#  return sprintf "%-40s %s", "$module $version", $file;
-#}
-
 sub _fmtmodule {
   my ( $module, $file, $version ) = @_;
-
-  $module .= ' ' while ( length( $module ) + length( $version ) < 38 );
-
-  return "$module $version  $file";
+  my $fw = 38 - length $version;
+  $fw = length $module if $fw < length $module;
+  return sprintf "%-${fw}s %s  %s", $module, $version, $file;
 }
 
 sub _cfg { $_[0]->{config}{ $_[1] } }
@@ -678,9 +657,9 @@ sub _fmtdate {
 
 L<CPAN::Mini>
 
-=head1 Maintainer
+=head1 Current Maintainer
 
-Andy Armstrong, C<< <andy@hexten.net> >>
+Christian Walde C<< <walde.christian@googlemail.com> >>
 
 =head1 Original Author
 
